summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouch.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:18 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:12:18 -0600
commitee52bb567f32fefdcf06e083c76562ea40ccf174 (patch)
tree8926667faaed3a18bec210ec14ffb9392ea8930d /ktouch/src/ktouch.h
parent088cc453ec425bf86d610880d09645ea166a14fa (diff)
downloadtdeedu-ee52bb567f32fefdcf06e083c76562ea40ccf174.tar.gz
tdeedu-ee52bb567f32fefdcf06e083c76562ea40ccf174.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'ktouch/src/ktouch.h')
-rw-r--r--ktouch/src/ktouch.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/ktouch/src/ktouch.h b/ktouch/src/ktouch.h
index 85697d59..dd7f859d 100644
--- a/ktouch/src/ktouch.h
+++ b/ktouch/src/ktouch.h
@@ -26,9 +26,9 @@
#include <kurl.h>
class TQLabel;
-class KToggleAction;
-class KActionMenu;
-class KSelectAction;
+class TDEToggleAction;
+class TDEActionMenu;
+class TDESelectAction;
class KTouchStatus;
class KTouchSlideLine;
@@ -48,7 +48,7 @@ class KTouchPrefColorsLayout;
/// It handles the lecture, training data, status and all other widgets that are
/// needed to get the program running. Since all special tasks are delegated to the
/// appropriate widgets and classes, the remaining code in KTouch is basically the
/// startup and KAction stuff.<p>
/// A word about dialogs. All dialogs in this program are not created by default.
/// Instead they are created "on first use". This
/// saves memory (because we don't need them always) and the startup speed increases.<p>
@@ -56,7 +56,7 @@ class KTouchPrefColorsLayout;
/// typed char. It delegates the character to the trainer
/// (KTouchTrainer), which will then process it. So the heavy work lies in the trainer
/// object and all the widgets.
-class KTouch : public KMainWindow {
+class KTouch : public TDEMainWindow {
Q_OBJECT
public:
@@ -148,11 +148,11 @@ class KTouch : public KMainWindow {
void updateKeyboardActionCheck();
// *** Public member variables ***
- KAction *m_trainingPause; ///< Action for "pause training session".
+ TDEAction *m_trainingPause; ///< Action for "pause training session".
- KSelectAction *m_keyboardLayoutAction;
- KSelectAction *m_keyboardColorAction;
- KSelectAction *m_defaultLectureAction;
+ TDESelectAction *m_keyboardLayoutAction;
+ TDESelectAction *m_keyboardColorAction;
+ TDESelectAction *m_defaultLectureAction;
KTouchStatus *m_statusWidget; ///< Pointer to the status widget on top of the main widget.
KTouchSlideLine *m_slideLineWidget; ///< Pointer to the sliding line widget.
@@ -48,7 +48,7 @@ class KTouchPrefColorsLayout;
/// needed to get the program running. Since all special tasks are delegated to the
/// appropriate widgets and classes, the remaining code in KTouch is basically the
-/// startup and KAction stuff.<p>
+/// startup and TDEAction stuff.<p>
/// A word about dialogs. All dialogs in this program are not created by default.
/// Instead they are created "on first use". This